==> IntuneCD-2.0.9b1.tar.gz: IntuneCD-2.0.9b1/src/IntuneCD/backup/Intune/backup_windowsEnrollmentProfile.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
This module backs up all Windows Enrollment Profiles in Intune.
"""

from ...intunecdlib.check_prefix import check_prefix_match
from ...intunecdlib.clean_filename import clean_filename
from ...intunecdlib.graph_batch import batch_assignment, get_object_assignment
from ...intunecdlib.graph_request import makeapirequest
from ...intunecdlib.remove_keys import remove_keys
from ...intunecdlib.save_output import save_output

# Set MS Graph endpoint
ENDPOINT = "https://graph.microsoft.com/beta/deviceManagement/windowsAutopilotDeploymentProfiles"


# Get all Windows Enrollment Profiles and save them in specified path
def savebackup(path, output, exclude, token, prefix, append_id):
    """
    Saves all Windows Enrollment Profiles in Intune to a JSON or YAML file.

    :param path: Path to save the backup to
    :param output: Format the backup will be saved as
    :param exclude: If "assignments" is in the list, it will not back up the assignments
    :param token: Token to use for authenticating the request
    """

    results = {"config_count": 0, "outputs": []}
    configpath = path + "/" + "Enrollment Profiles/Windows/"
    data = makeapirequest(ENDPOINT, token)

    assignment_responses = batch_assignment(
        data,
        "deviceManagement/windowsAutopilotDeploymentProfiles/",
        "/assignments",
        token,
    )

    for profile in data["value"]:
        if prefix and not check_prefix_match(profile["displayName"], prefix):
            continue

        results["config_count"] += 1
        if "assignments" not in exclude:
            assignments = get_object_assignment(profile["id"], assignment_responses)
            if assignments:
                profile["assignments"] = assignments

        graph_id = profile["id"]
        profile = remove_keys(profile)

        print("Backing up Autopilot enrollment profile: " + profile["displayName"])

        # Get filename without illegal characters
        fname = clean_filename(profile["displayName"])
        if append_id:
            fname = f"{fname}__{graph_id}"
        # Save Windows Enrollment Profile as JSON or YAML depending on
        # configured value in "-o"
        save_output(output, configpath, fname, profile)

        results["outputs"].append(fname)

    return results

==> IntuneCD-2.2.0b1.tar.gz: IntuneCD-2.2.0b1/src/IntuneCD/backup/Intune/backup_windowsEnrollmentProfile.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
This module backs up all Windows Enrollment Profiles in Intune.
"""

from ...intunecdlib.check_prefix import check_prefix_match
from ...intunecdlib.clean_filename import clean_filename
from ...intunecdlib.graph_batch import batch_assignment, get_object_assignment
from ...intunecdlib.graph_request import makeapirequest, makeAuditRequest
from ...intunecdlib.process_audit_data import process_audit_data
from ...intunecdlib.remove_keys import remove_keys
from ...intunecdlib.save_output import save_output

# Set MS Graph endpoint
ENDPOINT = "https://graph.microsoft.com/beta/deviceManagement/windowsAutopilotDeploymentProfiles"


# Get all Windows Enrollment Profiles and save them in specified path
def savebackup(path, output, exclude, token, prefix, append_id, audit):
    """
    Saves all Windows Enrollment Profiles in Intune to a JSON or YAML file.

    :param path: Path to save the backup to
    :param output: Format the backup will be saved as
    :param exclude: If "assignments" is in the list, it will not back up the assignments
    :param token: Token to use for authenticating the request
    """

    results = {"config_count": 0, "outputs": []}
    configpath = path + "/" + "Enrollment Profiles/Windows/"
    data = makeapirequest(ENDPOINT, token)

    assignment_responses = batch_assignment(
        data,
        "deviceManagement/windowsAutopilotDeploymentProfiles/",
        "/assignments",
        token,
    )

    for profile in data["value"]:
        if prefix and not check_prefix_match(profile["displayName"], prefix):
            continue

        results["config_count"] += 1
        if "assignments" not in exclude:
            assignments = get_object_assignment(profile["id"], assignment_responses)
            if assignments:
                profile["assignments"] = assignments

        graph_id = profile["id"]
        profile = remove_keys(profile)

        print("Backing up Autopilot enrollment profile: " + profile["displayName"])

        # Get filename without illegal characters
        fname = clean_filename(profile["displayName"])
        if append_id:
            fname = f"{fname}__{graph_id}"
        # Save Windows Enrollment Profile as JSON or YAML depending on
        # configured value in "-o"
        save_output(output, configpath, fname, profile)

        results["outputs"].append(fname)

        if audit:
            audit_data = makeAuditRequest(
                graph_id,
                "",
                token,
            )
            if audit_data:
                process_audit_data(audit_data, path, f"{configpath}{fname}.{output}")

    return results
